ena.rotate.by.mean: ENA Rotate by mean

View source: R/ena.rotate.by.mean.R

ena.rotate.by.meanR Documentation

ENA Rotate by mean

Description

Computes a dimensional reduction from a matrix of points such that the first dimension of the projected space passes through the means of two groups in a the original space. Subsequent dimensions of the projected space are computed using ena.svd

Usage

ena.rotate.by.mean(enaset, groups = NULL, params = groups)

Arguments

enaset

An ENAset

groups

A list containing two logical vectors of length nrow(ENA.set$ena.data$units), where each vector defines whether a unit is in one of the two groups whose means are used to determine the dimensional reduction

params

A list containing two vectors of length nrow(ENA.set$ena.data$units),

Value

ENARotationSet


rENA documentation built on Feb. 11, 2026, 5:06 p.m.