Learn R Programming

rENA (version 0.3.1)

rENA: rENA creates ENA sets

Description

rENA is used to create and visualize network models of discourse and other phenomena from coded data using Epistemic Network Analysis (ENA). A more complete description of the methods will be provided with the next release. See also XXXXX

Arguments